pub fn find_similar(ctx: &SomaContext, params: &Value) -> ToolCallResultExpand description
Retrieve: rank past experiments against a description of the problem at hand.
pub fn find_similar(ctx: &SomaContext, params: &Value) -> ToolCallResultRetrieve: rank past experiments against a description of the problem at hand.