pub fn lineage(ctx: &SomaContext, params: &Value) -> ToolCallResultExpand description
The experiment tree around one run, with the move on every edge.
pub fn lineage(ctx: &SomaContext, params: &Value) -> ToolCallResultThe experiment tree around one run, with the move on every edge.