pub fn stats(ctx: &SomaContext, _params: &Value) -> ToolCallResultExpand description
Orientation: how big the pool is and how much of it is usable.
pub fn stats(ctx: &SomaContext, _params: &Value) -> ToolCallResultOrientation: how big the pool is and how much of it is usable.